@@ -323,7 +323,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
                 if N.exists(): files.add(N)
             except: pass
 
-    env.Command(out, list(files) + [os.join(basename, ".sconsign.dblite")], "tar cjvf $TARGET $SOURCES")
+    env.Command(out, list(files) + [os.path.join(basename, ".sconsign.dblite")], "tar cjvf $TARGET $SOURCES")
 
     return targets, sources, basename
 
